@@ -129,7 +129,8 @@ def _ascii_chart(df: pd.DataFrame, COLS: int):
             derivative10.append((line[-1] - line[-11]) / (10 * step))
         current += step
     # mean rate
-    mean = [len(df) / (df.end.max() - df.start.min())] * len(derivative1)
+    mean_rate = len(df) / (df.end.max() - df.start.min())
+    mean_rate_line = [mean_rate] * len(derivative1)
 
     left = Section(
         plot(line, {"height": 10}), title=f"Number of generation [{step}s step)]"
@@ -137,9 +138,9 @@ def _ascii_chart(df: pd.DataFrame, COLS: int):
 
     config = dict(height=10, colors=[lightmagenta, blue, green])
     right = Section(
-        plot([mean, derivative1, derivative10], config),
+        plot([mean_rate_line, derivative1, derivative10], config),
         title=f"Generation rate (/s) ",
-        caption=f"{colored('mean rate', lightmagenta)} \nsliding windows of {colored('1*step', blue)}, {colored('10*step', green)}",
+        caption=f"{colored('Mean rate ', lightmagenta)}: {round(mean_rate, 2)} \nSliding windows of {colored('1*step', blue)}, {colored('10*step', green)}",
     )
     print(Row([left, right]))
 
@@ -163,14 +164,14 @@ def _stats(df: pd.DataFrame):
     s2 = Section(
         df.groupby(pd.cut(df.process, bins=10, precision=1))
         .count()
-        .process.to_string(),
+        .process
+        .to_string(),
         title="Process time distribution",
     )
-    by_error = df.groupby("error").count().process
-    content = by_error.to_string()
-    if by_error.empty:
-        content = "No processing error detected."
-
+    by_error = df.error.count()
+    content = "No processing error detected."
+    if by_error > 0:
+        content = f"{by_error} errors detected"
     s3 = Section(content, title="Processing errors")
     print(Row([s1, s2, s3], title=title))
 
